@@ -248,6 +248,9 @@ INVALIDPARAMETERVALUE_INVALIDIPV6 = 'InvalidParameterValue.InvalidIpv6'
 # 该Tag不合法。
 INVALIDPARAMETERVALUE_INVALIDTAG = 'InvalidParameterValue.InvalidTag'
 
+# 未查询到该IPv6翻译器。
+INVALIDPARAMETERVALUE_IP6TRANSLATORNOTFOUND = 'InvalidParameterValue.Ip6TranslatorNotFound'
+
 # 负载均衡实例已经绑定了EIP。
 INVALIDPARAMETERVALUE_LBALREADYBINDEIP = 'InvalidParameterValue.LBAlreadyBindEip'
 
@@ -284,6 +287,9 @@ INVALIDPARAMETERVALUE_NATGATEWAYDNATRULENOTEXISTS = 'InvalidParameterValue.NatGa
 # DNAT转换规则的内网IP需为虚拟机上网卡所用的IP。
 INVALIDPARAMETERVALUE_NATGATEWAYDNATRULEPIPNEEDVM = 'InvalidParameterValue.NatGatewayDnatRulePipNeedVm'
 
+# 新增NAT网关的DNAT转换规则已重复。
+INVALIDPARAMETERVALUE_NATGATEWAYDNATRULEREPEATED = 'InvalidParameterValue.NatGatewayDnatRuleRepeated'
+
 # NAT网关的SNAT转换规则不存在。
 INVALIDPARAMETERVALUE_NATGATEWAYSNATRULENOTEXISTS = 'InvalidParameterValue.NatGatewaySnatRuleNotExists'
 
@@ -446,12 +452,18 @@ LIMITEXCEEDED = 'LimitExceeded'
 # 账号退还配额超过限制。
 LIMITEXCEEDED_ACCOUNTRETURNQUOTA = 'LimitExceeded.AccountReturnQuota'
 
+# 接口请求次数超过限频。
+LIMITEXCEEDED_ACTIONLIMITED = 'LimitExceeded.ActionLimited'
+
 # 分配IP地址数量达到上限。
 LIMITEXCEEDED_ADDRESS = 'LimitExceeded.Address'
 
 # 租户申请的弹性IP超过上限。
 LIMITEXCEEDED_ADDRESSQUOTALIMITEXCEEDED = 'LimitExceeded.AddressQuotaLimitExceeded'
 
+# 实例关联快照策略数量达到上限。
+LIMITEXCEEDED_ATTACHEDSNAPSHOTPOLICYEXCEEDED = 'LimitExceeded.AttachedSnapshotPolicyExceeded'
+
 # 带宽包配额超过限制。
 LIMITEXCEEDED_BANDWIDTHPACKAGEQUOTA = 'LimitExceeded.BandwidthPackageQuota'
 
@@ -461,6 +473,9 @@ LIMITEXCEEDED_CHANGEADDRESSQUOTA = 'LimitExceeded.ChangeAddressQuota'
 # VPC分配网段数量达到上限。
 LIMITEXCEEDED_CIDRBLOCK = 'LimitExceeded.CidrBlock'
 
+# 当前实例关联的云联网数量达到上限。
+LIMITEXCEEDED_CURRENTINSTANCEATTACHEDCCNINSTANCES = 'LimitExceeded.CurrentInstanceAttachedCcnInstances'
+
 # 租户每天申请的弹性IP超过上限。
 LIMITEXCEEDED_DAILYALLOCATEADDRESSQUOTALIMITEXCEEDED = 'LimitExceeded.DailyAllocateAddressQuotaLimitExceeded'
 
@@ -629,6 +644,9 @@ UNSUPPORTEDOPERATION_CIDRUNSUPPORTEDCLASSICLINK = 'UnsupportedOperation.CIDRUnSu
 # 实例已关联CCN。
 UNSUPPORTEDOPERATION_CCNATTACHED = 'UnsupportedOperation.CcnAttached'
 
+# 云联网实例不支持跨账号关联。
+UNSUPPORTEDOPERATION_CCNCROSSACCOUNT = 'UnsupportedOperation.CcnCrossAccount'
+
 # 当前云联网有流日志，不支持删除。
 UNSUPPORTEDOPERATION_CCNHASFLOWLOG = 'UnsupportedOperation.CcnHasFlowLog'
 
@@ -701,6 +719,9 @@ UNSUPPORTEDOPERATION_ECMPWITHCCNROUTE = 'UnsupportedOperation.EcmpWithCcnRoute'
 # 和用户自定义的路由形成ECMP。
 UNSUPPORTEDOPERATION_ECMPWITHUSERROUTE = 'UnsupportedOperation.EcmpWithUserRoute'
 
+# 当前地域不支持启用组播。
+UNSUPPORTEDOPERATION_ENABLEMULTICAST = 'UnsupportedOperation.EnableMulticast'
+
 # 终端节点服务本身不能是终端节点。
 UNSUPPORTEDOPERATION_ENDPOINTSERVICE = 'UnsupportedOperation.EndPointService'
 
@@ -773,12 +794,18 @@ UNSUPPORTEDOPERATION_MUTEXOPERATIONTASKRUNNING = 'UnsupportedOperation.MutexOper
 # NAT网关的公网IP不存在。
 UNSUPPORTEDOPERATION_NATGATEWAYEIPNOTEXISTS = 'UnsupportedOperation.NatGatewayEipNotExists'
 
+# NAT网关存在未解绑的IP。
+UNSUPPORTEDOPERATION_NATGATEWAYHADEIPUNASSOCIATE = 'UnsupportedOperation.NatGatewayHadEipUnassociate'
+
 # SNAT/DNAT转换规则所指定的内网IP已绑定了其他的规则，无法重复绑定。
 UNSUPPORTEDOPERATION_NATGATEWAYRULEPIPEXISTS = 'UnsupportedOperation.NatGatewayRulePipExists'
 
 # SNAT转换规则的内网IP需为虚拟机上网卡所用的IP。
 UNSUPPORTEDOPERATION_NATGATEWAYSNATPIPNEEDVM = 'UnsupportedOperation.NatGatewaySnatPipNeedVm'
 
+# NAT网关的SNAT转换规则不存在。
+UNSUPPORTEDOPERATION_NATGATEWAYSNATRULENOTEXISTS = 'UnsupportedOperation.NatGatewaySnatRuleNotExists'
+
 # NAT网关类型不支持SNAT规则。
 UNSUPPORTEDOPERATION_NATGATEWAYTYPENOTSUPPORTSNAT = 'UnsupportedOperation.NatGatewayTypeNotSupportSNAT'
 
@@ -851,6 +878,9 @@ UNSUPPORTEDOPERATION_RECORDEXISTS = 'UnsupportedOperation.RecordExists'
 # 记录不存在。
 UNSUPPORTEDOPERATION_RECORDNOTEXISTS = 'UnsupportedOperation.RecordNotExists'
 
+# 资源处于不可用状态，禁止操作。
+UNSUPPORTEDOPERATION_RESOURCEISINVALIDSTATE = 'UnsupportedOperation.ResourceIsInvalidState'
+
 # 输入的资源ID与IP绑定的资源不匹配，请检查。
 UNSUPPORTEDOPERATION_RESOURCEMISMATCH = 'UnsupportedOperation.ResourceMismatch'
 
